"""Added file/dir name to PeekPluginInfo

Revision ID: bc1622f6c16c
Revises: c5e78990adf6
Create Date: 2016-11-05 17:58:21.169972

"""

# revision identifiers, used by Alembic.
revision = 'bc1622f6c16c'
down_revision = 'c5e78990adf6'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('PeekPluginInfo', sa.Column('dirName', sa.String(), nullable=False), schema='peek_server')
    op.add_column('PeekPluginInfo', sa.Column('fileName', sa.String(), nullable=False), schema='peek_server')
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('PeekPluginInfo', 'fileName', schema='peek_server')
    op.drop_column('PeekPluginInfo', 'dirName', schema='peek_server')
    ### end Alembic commands ###
